export declare type CookieAuthenticationCredentialConfiguration = {
    url: string;
    guest?: boolean;
};
export declare class CookieAuthenticationCredential {
    private _config;
    private _server;
    constructor(config: CookieAuthenticationCredentialConfiguration);
    private _getAuthenticationInfo;
    private _setStoreStatus;
    /**
     * Checks the server endpoint to see if the user is authenticated. If there is not user session
     * and any config enabled guest, then a guest session will be created. Otherwise false will be
     * returned.
     * @returns true if authenticated
     */
    private _checkEndpoint;
    /**
     * Checks to see if any user is authenticated.
     *
     * @rejects: If no user is authenticated.
     */
    checkAuthenticated(): Promise<void>;
    /**
     * Launches a popup window that navigates to the authentication endpoint and allows the user to login.
     *
     * @rejects: When login fails (for example: user closes the popup).
     */
    loginPopup(): Promise<void>;
    /**
     * Makes endpoint call to end the current cookie session.
     *
     * @rejects: When logout fails.
     */
    logout(): Promise<void>;
    /**
     * If `checkAuthenticated` has already been called, a cached value may be returned the next time.
     * This is done to reduce the number of potential service calls needed when making multiple API
     * calls. Calling `invalidateCache` will force `checkAuthenticated` to re-validate the next time
     * it is called. **This is not needed for most use cases.**
     */
    invalidateCache(): void;
}
//# sourceMappingURL=CookieAuthenticationCredential.d.ts.map