const global = globalThis;
global.__sasAuthPopover = global.__sasAuthPopover || undefined;
function removeCurrentPopup() {
    const oldPopover = __sasAuthPopover;
    if (!oldPopover) {
        return;
    }
    __sasAuthPopover = undefined;
    oldPopover.close();
}
class Popup {
    constructor(url, title) {
        this._closed = true;
        this._url = url;
        this._title = title;
    }
    open() {
        var _a;
        this._closed = this.popup ? this.popup.closed : true;
        if (__sasAuthPopover && __sasAuthPopover === this.popup && !this._closed) {
            (_a = this.popup) === null || _a === void 0 ? void 0 : _a.focus();
            return;
        }
        const top = window.outerHeight / 2 + window.screenY - 600 / 2;
        const left = window.outerWidth / 2 + window.screenX - 700 / 2;
        const popup = window.open(this._url, this._title, `width=700,height=600,top=${top},left=${left}`);
        if (popup && !popup.closed) {
            this._closed = false;
            this.popup = popup;
            __sasAuthPopover = popup;
        }
    }
    close() {
        if (__sasAuthPopover === this.popup) {
            removeCurrentPopup();
        }
    }
}
class PopupWithMessage extends Popup {
    _rejectPromise() {
        var _a;
        if (!this._resolutionPromise) {
            return;
        }
        if (this._messageCb) {
            window.removeEventListener('message', this._messageCb);
        }
        clearInterval(this._intervalId);
        this._messageCb = undefined;
        this._resolutionPromise = undefined;
        this._resolve = undefined;
        (_a = this._reject) === null || _a === void 0 ? void 0 : _a.call(this);
        this._reject = undefined;
    }
    _acceptPromise() {
        var _a;
        if (!this._resolutionPromise) {
            return;
        }
        if (this._messageCb) {
            window.removeEventListener('message', this._messageCb);
        }
        clearInterval(this._intervalId);
        this._messageCb = undefined;
        this._resolutionPromise = undefined;
        this._reject = undefined;
        (_a = this._resolve) === null || _a === void 0 ? void 0 : _a.call(this);
        this._resolve = undefined;
    }
    open() {
        super.open();
        if (!this._closed) {
            this._resolutionPromise = new Promise((resolve, reject) => {
                this._resolve = resolve;
                this._reject = reject;
                this._messageCb = (event) => {
                    if (this._url.indexOf(event.origin) !== -1 && event.data && event.data.logonStatus) {
                        this._acceptPromise();
                    }
                };
                window.addEventListener('message', this._messageCb);
                this._intervalId = window.setInterval(() => {
                    var _a;
                    (_a = this.popup) === null || _a === void 0 ? void 0 : _a.postMessage('register', '*');
                }, 250);
            });
        }
    }
    waitForMessage() {
        if (this._resolutionPromise) {
            return this._resolutionPromise;
        }
        return Promise.reject();
    }
    close() {
        super.close();
        this._rejectPromise();
    }
}
export function openMessagePopup(location, title) {
    const popup = new PopupWithMessage(location, title);
    popup.open();
    return popup.waitForMessage().then(() => popup.close());
}
//# sourceMappingURL=PopupHelper.js.map